import ec2 = require('@aws-cdk/aws-ec2');
import { Construct } from '@aws-cdk/cdk';
import { BaseNamespaceProps, INamespace, NamespaceBase, NamespaceType } from './namespace';
import { DnsServiceProps, Service } from './service';
export interface PrivateDnsNamespaceProps extends BaseNamespaceProps {
    /**
     * The Amazon VPC that you want to associate the namespace with.
     */
    readonly vpc: ec2.IVpcNetwork;
}
export interface IPrivateDnsNamespace extends INamespace {
    /**
     * The ID of the private namespace.
     * @attribute
     */
    readonly privateDnsNamespaceId: string;
    /**
     * The Amazon Resource Name (ARN) of the private namespace.
     * @attribute
     */
    readonly privateDnsNamespaceArn: string;
}
/**
 * Define a Service Discovery HTTP Namespace
 */
export declare class PrivateDnsNamespace extends NamespaceBase implements IPrivateDnsNamespace {
    /**
     * The name of the PrivateDnsNamespace.
     */
    readonly namespaceName: string;
    /**
     * Namespace Id of the PrivateDnsNamespace.
     */
    readonly namespaceId: string;
    /**
     * Namespace Arn of the namespace.
     */
    readonly namespaceArn: string;
    /**
     * Type of the namespace.
     */
    readonly type: NamespaceType;
    constructor(scope: Construct, id: string, props: PrivateDnsNamespaceProps);
    readonly privateDnsNamespaceArn: string;
    readonly privateDnsNamespaceId: string;
    /**
     * Creates a service within the namespace
     */
    createService(id: string, props?: DnsServiceProps): Service;
}
