import { Construct } from '@aws-cdk/cdk';
import { BaseNamespaceProps, INamespace, NamespaceBase, NamespaceType } from './namespace';
import { DnsServiceProps, Service } from './service';
export interface PublicDnsNamespaceProps extends BaseNamespaceProps {
}
export interface IPublicDnsNamespace extends INamespace {
    /**
     * The ID of the public namespace.
     * @attribute
     */
    readonly publicDnsNamespaceId: string;
    /**
     * The Amazon Resource Name (ARN) of the public namespace.
     * @attribute
     */
    readonly publicDnsNamespaceArn: string;
}
/**
 * Define a Public DNS Namespace
 */
export declare class PublicDnsNamespace extends NamespaceBase implements IPublicDnsNamespace {
    /**
     * A name for the namespace.
     */
    readonly namespaceName: string;
    /**
     * Namespace Id for the namespace.
     */
    readonly namespaceId: string;
    /**
     * Namespace Arn for the namespace.
     */
    readonly namespaceArn: string;
    /**
     * Type of the namespace.
     */
    readonly type: NamespaceType;
    constructor(scope: Construct, id: string, props: PublicDnsNamespaceProps);
    readonly publicDnsNamespaceArn: string;
    readonly publicDnsNamespaceId: string;
    /**
     * Creates a service within the namespace
     */
    createService(id: string, props?: DnsServiceProps): Service;
}
